@@ -20,7 +20,7 @@ pub use internednames::{InternedName, InternedNames};
 mod priority_queue;
 pub use priority_queue::{PriorityQueue, QueueEntry, ReceiveGuard};
 pub use openat_ct as openat;
-pub use easy_error::{Error, ResultExt};
+pub use easy_error::{Error, ResultExt}; //PLANNED: needs some other kind of error handling
 
 #[cfg(test)]
 mod test {
